@@ -25,7 +25,7 @@ def pdf():
     parser.add_argument(
         '-x', '--exportdata', action='store_true', help='Save CSV of word frequency data')
     parser.add_argument(
-        '-n', 'filename', help='Optional name of data and wordcloud files (omit .pdf/.csv)')
+        '-n', '--filename', help='Optional name of data and wordcloud files (omit .pdf/.csv)')
 
     args = parser.parse_args()
 
